Enum ocl::builders::BuildOpt
[−]
[src]
pub enum BuildOpt {
CmplrDefine {
ident: String,
val: String,
},
CmplrInclDir {
path: String,
},
CmplrOther(String),
IncludeDefine {
ident: String,
val: String,
},
IncludeRaw(String),
IncludeRawEof(String),
}A build option used by ProgramBuilder.
Strings intended for use either by the compiler as a command line switch or for inclusion in the final build source code.
A few of the often used variants have constructors for convenience.
-
[FIXME] TODO: Explain how each variant is used.
-
[FIXME] TODO: Examples.
Variants
CmplrDefineFields of CmplrDefine
ident: String | |
val: String |
CmplrInclDirFields of CmplrInclDir
path: String |
CmplrOther(String)IncludeDefineFields of IncludeDefine
ident: String | |
val: String |
IncludeRaw(String)IncludeRawEof(String)Methods
impl BuildOpt[src]
fn cmplr_def<S: Into<String>>(ident: S, val: i32) -> BuildOpt
Returns a BuildOpt::CmplrDefine.
fn include_def<S: Into<String>>(ident: S, val: String) -> BuildOpt
Returns a BuildOpt::IncludeDefine.